@@ -1,22 +1,18 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-from collections import defaultdict
-
 import copy
-import inspect
 import logging
+from collections import defaultdict
+from inspect import isclass
+
+try:
+    from inspect import getfullargspec as get_args
+except ImportError:
+    from inspect import getfullargspec as get_args  # type: ignore
 
 _MYPY = False
 if _MYPY:
     import typing  # noqa: F401 # pylint: disable=import-error,unused-import,useless-suppression
 
-# Hack to get around some of Python 2's standard library modules that
-# accept ascii-encodable unicode literals in lieu of strs, but where
-# actually passing such literals results in errors with mypy --py2. See
-# <https://github.com/python/typeshed/issues/756> and
-# <https://github.com/python/mypy/issues/2536>.
-import importlib
-re = importlib.import_module(str('re'))  # type: typing.Any
+import re
 
 from ..ir import (
     Alias,
@@ -229,7 +225,7 @@ class Environment(dict):
     namespace_name = None  # type: typing.Optional[typing.Text]
 
 
-class IRGenerator(object):
+class IRGenerator:
 
     data_types = [
         Bytes,
@@ -566,7 +562,7 @@ class IRGenerator(object):
                                   ast_node=item)
             except ParameterError as e:
                 raise InvalidSpec(
-                    'Bad declaration of %s: %s' % (quote(item.name), e.args[0]),
+                    'Bad declaration of {}: {}'.format(quote(item.name), e.args[0]),
                     item.lineno, item.path)
         elif isinstance(item, AstUnionDef):
             api_type = Union(
@@ -1074,7 +1070,7 @@ class IRGenerator(object):
         assert issubclass(data_type_class, DataType), \
             'Expected stone.data_type.DataType, got %r' % data_type_class
 
-        argspec = inspect.getfullargspec(data_type_class.__init__)  # noqa: E501 # pylint: disable=deprecated-method,useless-suppression
+        argspec = get_args(data_type_class.__init__)  # noqa: E501 # pylint: disable=deprecated-method,useless-suppression
         argspec.args.remove('self')
         num_args = len(argspec.args)
         # Unfortunately, argspec.defaults is None if there are no defaults
@@ -1154,7 +1150,7 @@ class IRGenerator(object):
         if obj is Void and type_ref.nullable:
             raise InvalidSpec('Void cannot be marked nullable.',
                               *loc)
-        elif inspect.isclass(obj):
+        elif isclass(obj):
             resolved_data_type_args = self._resolve_args(env, type_ref.args)
             data_type = self._instantiate_data_type(
                 obj, resolved_data_type_args, (type_ref.lineno, type_ref.path))
